==> opensearch-py-2.7.1.gh.tar.gz: opensearch-py-2.7.1/test_opensearchpy/test_client/test_cluster.py <==
# SPDX-License-Identifier: Apache-2.0
#
# The OpenSearch Contributors require contributions made to
# this file be licensed under the Apache-2.0 license or a
# compatible open source license.
#
# Modifications Copyright OpenSearch Contributors. See
# GitHub history for details.
#
#  Licensed to Elasticsearch B.V. under one or more contributor
#  license agreements. See the NOTICE file distributed with
#  this work for additional information regarding copyright
#  ownership. Elasticsearch B.V. licenses this file to you under
#  the Apache License, Version 2.0 (the "License"); you may
#  not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing,
#  software distributed under the License is distributed on an
#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#  KIND, either express or implied.  See the License for the
#  specific language governing permissions and limitations
#  under the License.


from test_opensearchpy.test_cases import OpenSearchTestCase


class TestCluster(OpenSearchTestCase):
    def test_stats_without_node_id(self) -> None:
        self.client.cluster.stats()
        self.assert_url_called("GET", "/_cluster/stats")

    def test_stats_with_node_id(self) -> None:
        self.client.cluster.stats("node-1")
        self.assert_url_called("GET", "/_cluster/stats/nodes/node-1")

        self.client.cluster.stats(node_id="node-2")
        self.assert_url_called("GET", "/_cluster/stats/nodes/node-2")

    def test_state_with_index_without_metric_defaults_to_all(self) -> None:
        self.client.cluster.state()
        self.assert_url_called("GET", "/_cluster/state")

        self.client.cluster.state(metric="cluster_name")
        self.assert_url_called("GET", "/_cluster/state/cluster_name")

        self.client.cluster.state(index="index-1")
        self.assert_url_called("GET", "/_cluster/state/_all/index-1")

        self.client.cluster.state(index="index-1", metric="cluster_name")
        self.assert_url_called("GET", "/_cluster/state/cluster_name/index-1")

==> opensearch-py-3.0.0.gh.tar.gz: opensearch-py-3.0.0/test_opensearchpy/test_client/test_cluster.py <==
# SPDX-License-Identifier: Apache-2.0
#
# The OpenSearch Contributors require contributions made to
# this file be licensed under the Apache-2.0 license or a
# compatible open source license.
#
# Modifications Copyright OpenSearch Contributors. See
# GitHub history for details.
#
#  Licensed to Elasticsearch B.V. under one or more contributor
#  license agreements. See the NOTICE file distributed with
#  this work for additional information regarding copyright
#  ownership. Elasticsearch B.V. licenses this file to you under
#  the Apache License, Version 2.0 (the "License"); you may
#  not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing,
#  software distributed under the License is distributed on an
#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#  KIND, either express or implied.  See the License for the
#  specific language governing permissions and limitations
#  under the License.


from test_opensearchpy.test_cases import OpenSearchTestCase


class TestCluster(OpenSearchTestCase):
    def test_stats_without_node_id(self) -> None:
        self.client.cluster.stats()
        self.assert_url_called("GET", "/_cluster/stats")

    def test_stats_with_node_id(self) -> None:
        self.client.cluster.stats(node_id="node-1")
        self.assert_url_called("GET", "/_cluster/stats/nodes/node-1")

        self.client.cluster.stats(node_id="node-2")
        self.assert_url_called("GET", "/_cluster/stats/nodes/node-2")

    def test_state_with_index_without_metric_defaults_to_all(self) -> None:
        self.client.cluster.state()
        self.assert_url_called("GET", "/_cluster/state")

        self.client.cluster.state(metric="cluster_name")
        self.assert_url_called("GET", "/_cluster/state/cluster_name")

        self.client.cluster.state(index="index-1")
        self.assert_url_called("GET", "/_cluster/state/_all/index-1")

        self.client.cluster.state(index="index-1", metric="cluster_name")
        self.assert_url_called("GET", "/_cluster/state/cluster_name/index-1")
